[libcxx-commits] [PATCH] D115194: [libc++] Fix atomic test for _BitInt

Louis Dionne via Phabricator via libcxx-commits libcxx-commits at lists.llvm.org
Tue Dec 7 04:30:22 PST 2021


This revision was not accepted when it landed; it landed in state "Needs Review".
This revision was landed with ongoing or failed builds.
This revision was automatically updated to reflect the committed changes.
Closed by commit rGc49a13a45a0f: [libc++] Fix atomic test for _BitInt (authored by ldionne).

Changed prior to commit:
  https://reviews.llvm.org/D115194?vs=392263&id=392350#toc

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D115194/new/

https://reviews.llvm.org/D115194

Files:
  libcxx/test/libcxx/atomics/bit-int.verify.cpp
  libcxx/test/libcxx/atomics/ext-int.verify.cpp


Index: libcxx/test/libcxx/atomics/bit-int.verify.cpp
===================================================================
--- libcxx/test/libcxx/atomics/bit-int.verify.cpp
+++ libcxx/test/libcxx/atomics/bit-int.verify.cpp
@@ -8,11 +8,13 @@
 
 // <atomic>
 
 // Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
 
-// UNSUPPORTED: apple-clang-12
+// TODO(ldionne): Re-enable the test on clang-14 once 6c75ab5f66b4 lands in the CI.
+// UNSUPPORTED: apple-clang-12, apple-clang-13
+// UNSUPPORTED: clang-12, clang-13, clang-14
 
 // UNSUPPORTED: c++03
 
@@ -20,8 +22,8 @@
 
 int main(int, char**)
 {
-  // expected-error at atomic:*1 {{_Atomic cannot be applied to integer type '_ExtInt(32)'}}
-  std::atomic<_ExtInt(32)> x(42);
+  // expected-error at atomic:*1 {{_Atomic cannot be applied to integer type '_BitInt(32)'}}
+  std::atomic<_BitInt(32)> x(42);
 
   return 0;
 }


-------------- next part --------------
@@ -8,11 +8,13 @@
 // <atomic>
 
-// Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
+// Make sure that `std::atomic` doesn't work with `_BitInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
A non-text attachment was scrubbed...
Name: D115194.392350.patch
Type: text/x-patch
Size: 1099 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/libcxx-commits/attachments/20211207/f416f7a0/attachment-0001.bin>


More information about the libcxx-commits mailing list